using System;
using System.Threading;
using Common.Logging;
using Quartz;

namespace IBO.XJMYQP.JobServices
{
    /// <summary>
    /// A sample job that just prints info on console for demostration purposes.
    /// </summary>
    public class SampleJob : IJob
    {
        private static readonly ILog logger = LogManager.GetLogger(typeof(SampleJob));

        /// <summary>
        /// Called by the <see cref="IScheduler" /> when a <see cref="ITrigger" />
        /// fires that is associated with the <see cref="IJob" />.
        /// </summary>
        /// <remarks>
        /// The implementation may wish to set a  result object on the 
        /// JobExecutionContext before this method exits.  The result itself
        /// is meaningless to Quartz, but may be informative to 
        /// <see cref="IJobListener" />s or 
        /// <see cref="ITriggerListener" />s that are watching the job's 
        /// execution.
        /// </remarks>
        /// <param name="context">The execution context.</param>
        public void Execute(IJobExecutionContext context)
        {
            logger.Info("------------------------begin-----------------------------------------------------");
            logger.Info("SampleJob running...");
            //Thread.Sleep(100000);
            //for (int i = 0; i < 10; i++)
            //{
            //    // logger.InfoFormat("SyncGasBottlesJob {0}", i);
            //}
            Thread.Sleep(TimeSpan.FromSeconds(5));
            logger.Info("SampleJob run finished.");
            logger.Info("------------------------end-------------------------------------------------------");
        }
    }
}